@@ -1,4 +1,4 @@
-from io import StringIO
+import io
 import os
 import zipfile
 
@@ -26,8 +26,21 @@ class Wheel(Distribution):
 
             def read_file(name):
                 return archive.read(name)
+
+            close = archive.close
+
+        elif fqn.endswith('.dist-info'):
+            names = [os.path.join(fqn, p) for p in os.listdir(fqn)]
+
+            def read_file(name):
+                with io.open(name, mode='rb') as inf:
+                    return inf.read()
+
+            close = lambda : None
+
         else:
-            raise ValueError('Not a known archive format: %s' % fqn)
+            raise ValueError('Not a known wheel archive format or '
+                             'installed .dist-info: %s' % fqn)
 
         try:
             tuples = [x.split('/') for x in names if 'METADATA' in x]
@@ -38,12 +51,12 @@ class Wheel(Distribution):
                 if b'Metadata-Version' in data:
                     return data
         finally:
-            archive.close()
+            close()
 
         raise ValueError('No METADATA in archive: %s' % fqn)
 
     def parse(self, data):
         super(Wheel, self).parse(data)
-        fp = StringIO(must_decode(data))
+        fp = io.StringIO(must_decode(data))
         msg = parse(fp)
         self.description = msg.get_payload()
